@@ -1,19 +1,15 @@
 """ A class for interacting with Aussie Broadband APIs """
 
 # import json
-from email.policy import default
-from http.cookiejar import CookieJar
-from http.cookies import SimpleCookie
-from re import M
 from time import time
-from typing import Any, Dict, List, Optional, cast, Union
+from typing import Any, Dict, List, Optional, cast
 
 import requests
 import requests.sessions
 
 from .baseclass import BaseClass
-from .const import BASEURL, DefaultHeaders, default_headers, PHONE_TYPES
-from .exceptions import InvalidTestForService, RecursiveDepth
+from .const import BASEURL, default_headers, PHONE_TYPES
+from .exceptions import RecursiveDepth, DeprecatedCall
 from .types import (
     FetchService,
     ServiceTest,
@@ -69,7 +65,7 @@ class AussieBB(BaseClass):
             "username": self.username,
             "password": self.password,
         }
-        headers = default_headers()
+        headers: Dict[str, Any] = dict(default_headers())
 
         response = self.session.post(
             url,
@@ -152,9 +148,14 @@ class AussieBB(BaseClass):
         if "cookies" not in kwargs:
             kwargs["cookies"] = {"myaussie_cookie": self.myaussie_cookie}
 
+        if "headers" in kwargs:
+            headers: Dict[str, Any] = kwargs["headers"]
+        else:
+            headers = dict(default_headers())
+
         response = self.session.post(
             url=url,
-            headers=kwargs.get("headers", default_headers()),
+            headers=headers,
             **kwargs,  # type: ignore
         )
         response.raise_for_status()
@@ -374,13 +375,17 @@ class AussieBB(BaseClass):
         return result
 
     def service_plans(self, service_id: int) -> Dict[str, Any]:
-        """Pulls the plan data for a given service.
+        """
+        *** DEPRECATED - This endpoint requires MFA now, which the library doesn't support! ***
+
+        Pulls the plan data for a given service.
 
         Keys: `['current', 'pending', 'available', 'filters', 'typicalEveningSpeeds']`
 
         """
-        url = self.get_url("service_plans", {"service_id": service_id})
-        return self.request_get_json(url=url)
+        raise DeprecatedCall("This endpoint requires MFA now, which the library doesn't support!")
+        #url = self.get_url("service_plans", {"service_id": service_id})
+        #return self.request_get_json(url=url)
 
     def service_outages(self, service_id: int) -> Dict[str, Any]:
         """Pulls outages associated with a service.
