@@ -7,6 +7,9 @@ class InvalidTestForService(BaseException):
 class AuthenticationException(BaseException):
     """authentication error for AussieBB"""
 
+class DeprecatedCall(BaseException):
+    """ Can't use this anymore """
+
 
 class RateLimitException(BaseException):
     """rate limit error for AussieBB"""
